@@ -3,9 +3,11 @@ from qtpyinheritance.properties import (PassthroughProperty,
                                         forward_properties, forward_property,
                                         get_qt_properties)
 
+from .designer_display import DesignerDisplay
 from .popbar import QPopBar
 
 __all__ = [
+    "DesignerDisplay",
     "QPopBar",
     "PassthroughProperty",
     "ReadonlyPassthroughProperty",
